import { Router } from 'express';
import { createCompilerOptions } from './lib/create-compiler-options';
import { createResolver } from './lib/create-resolver';
import { createSourceCodeProvider } from './lib/create-source-code-provider';
import { createTranspiler } from './lib/create-transpiler';
import { createLogger, LogLevel } from './lib/logger';
import { modulesPreloadHandle } from './lib/modules-preload-handle';
import { prepareConfig } from './lib/options';
import { modulesImportHandler } from './lib/modules-import-handler';
export * from './lib/utils/get-url-for-file';
/**
 * Creates instance of typescript compile middleware.
 * @public
 * @param options - options of middleware
 * @param logger - logging target, default `console`
 */
export function typescriptCompileMiddleware(options, logger) {
    if (options === void 0) { options = {}; }
    var preloadList = [];
    var config = prepareConfig(options);
    var cwd = config.cwd, compile = config.compile, resolve = config.resolve, cache = config.cache, logLevel = config.logLevel;
    var log = createLogger(logLevel, logger);
    var compilerOptions = createCompilerOptions(cwd, compile, log);
    var resolver = createResolver(cwd, compilerOptions, resolve, log);
    var transpiler = createTranspiler(cwd, compilerOptions, compile.transformers || [], resolver, preloadList);
    var sourceProvider = createSourceCodeProvider(cwd, cache, transpiler);
    var router = Router({ mergeParams: true });
    router.get('/modules-preload', modulesPreloadHandle(preloadList));
    router.get('*', modulesImportHandler(config, sourceProvider, log));
    return router;
}
export { LogLevel };
//# sourceMappingURL=index.js.map