import { __spreadArray } from "tslib";
import { isCallExpression, isExportDeclaration, isImportDeclaration, isStringLiteral, SyntaxKind, visitEachChild } from 'typescript';
import { getUrlForFile } from './utils/get-url-for-file';
/**
 * Create source code transformer
 * @internal
 * @param cwd - working dir
 * @param resolve - dependencies resolver
 * @param file - target file
 * @param preloadList - list modules to preload
 */
export function createImportsTransformer(cwd, resolve, file, preloadList) {
    /**
     * Creates import url.
     * @param target - for the dependency
     */
    var url = function (target) {
        var url;
        var resolution = resolve(file, target);
        if (resolution.isExternal) {
            url = resolution.resolution;
        }
        else if (resolution.isUrl) {
            url = resolution.resolution;
        }
        else {
            url = getUrlForFile(cwd, resolution.resolution);
        }
        if (preloadList.indexOf(url) < 0) {
            preloadList.push(url);
        }
        return url;
    };
    return function (context) {
        // creates visitor
        var visitor = function (node) {
            var _a;
            // dynamic import call
            if (isCallExpression(node) && node.expression.kind === SyntaxKind.ImportKeyword) {
                var _b = node.arguments, arg = _b[0], rest = _b.slice(1);
                if (isStringLiteral(arg)) {
                    return context.factory.updateCallExpression(node, node.expression, node.typeArguments, __spreadArray([
                        context.factory.createStringLiteral(url(arg.text))
                    ], rest, true));
                }
                // todo report problematic import
            }
            // export ... from ...
            if (isExportDeclaration(node) && !node.isTypeOnly) {
                var moduleSpecifier = node.moduleSpecifier;
                if (moduleSpecifier && isStringLiteral(moduleSpecifier)) {
                    return context.factory.updateExportDeclaration(node, node.modifiers, node.isTypeOnly, node.exportClause, context.factory.createStringLiteral(url(moduleSpecifier.text)), node.assertClause);
                }
            }
            // import ... from ...
            if (isImportDeclaration(node) && !((_a = node.importClause) === null || _a === void 0 ? void 0 : _a.isTypeOnly)) {
                var moduleSpecifier = node.moduleSpecifier;
                if (isStringLiteral(moduleSpecifier)) {
                    return context.factory.updateImportDeclaration(node, node.modifiers, node.importClause, context.factory.createStringLiteral(url(moduleSpecifier.text)), node.assertClause);
                }
                return node;
            }
            return visitEachChild(node, visitor, context);
        };
        return function (node) {
            return visitEachChild(node, visitor, context);
        };
    };
}
//# sourceMappingURL=create-imports-transformer.js.map