import { __assign, __spreadArray } from "tslib";
import { formatDiagnostics } from 'typescript';
/**
 * @public
 */
export var LogLevel = {
    void: 1,
    error: 2,
    warn: 3,
    info: 4,
    debug: 5,
};
/**
 * @internal
 */
export var loggerPrefix = 'express-typescript-compile:';
/**
 * @internal
 */
export var diagnosticToString = function (diagnostics, cwd) {
    return formatDiagnostics(diagnostics, {
        getCanonicalFileName: function (fileName) { return fileName; },
        getCurrentDirectory: function () { return cwd; },
        getNewLine: function () { return '\n'; }
    });
};
/**
 * @internal
 * @param level - logging level
 * @param baseLogger - base logger
 */
export var createLogger = function (level, baseLogger) {
    if (level === void 0) { level = LogLevel.warn; }
    if (baseLogger === void 0) { baseLogger = console; }
    return ['debug', 'info', 'warn', 'error'].reduce(function (logger, key) {
        var _a;
        return (__assign(__assign({}, logger), (_a = {}, _a[key] = function () {
            var data = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                data[_i] = arguments[_i];
            }
            if (level > (LogLevel[key] - 1)) {
                baseLogger[key].apply(baseLogger, __spreadArray([loggerPrefix], data, false));
            }
        }, _a)));
    }, {});
};
//# sourceMappingURL=logger.js.map